@@ -51,7 +51,7 @@ typedef struct
 {
 	GeditPluginsEngine *engine;
 
-	GtkCssProvider     *theme_provider;
+	GtkCssProvider *theme_provider;
 
 	GtkPageSetup      *page_setup;
 	GtkPrintSettings  *print_settings;
@@ -154,14 +154,7 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&priv->extensions);
 
 	g_clear_object (&priv->engine);
-
-	if (priv->theme_provider != NULL)
-	{
-		gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (),
-		                                              GTK_STYLE_PROVIDER (priv->theme_provider));
-		g_clear_object (&priv->theme_provider);
-	}
-
+	g_clear_object (&priv->theme_provider);
 	g_clear_object (&priv->hamburger_menu);
 	g_clear_object (&priv->notebook_menu);
 	g_clear_object (&priv->tab_width_menu);
@@ -321,19 +314,19 @@ open_files (GApplication            *application,
 		gtk_widget_show (GTK_WIDGET (window));
 	}
 
-	if (stdin_stream)
+	if (stdin_stream != NULL)
 	{
 		gedit_debug_message (DEBUG_APP, "Load stdin");
 
-		tab = gedit_window_create_tab_from_stream (window,
-		                                           stdin_stream,
-		                                           encoding,
-		                                           line_position,
-		                                           column_position,
-		                                           TRUE);
-		doc_created = tab != NULL;
+		tab = gedit_window_create_tab (window, TRUE);
+		gedit_tab_load_stream (tab,
+				       stdin_stream,
+				       encoding,
+				       line_position,
+				       column_position);
+		doc_created = TRUE;
 
-		if (doc_created && command_line)
+		if (command_line != NULL)
 		{
 			set_command_line_wait (GEDIT_APP (application),
 					       tab);
@@ -428,20 +421,6 @@ preferences_activated (GSimpleAction  *action,
 	gedit_show_preferences_dialog (window);
 }
 
-static void
-keyboard_shortcuts_activated (GSimpleAction *action,
-                              GVariant      *parameter,
-                              gpointer       user_data)
-{
-	GtkApplication *app;
-	GeditWindow *window;
-
-	app = GTK_APPLICATION (user_data);
-	window = GEDIT_WINDOW (gtk_application_get_active_window (app));
-
-	_gedit_cmd_help_keyboard_shortcuts (window);
-}
-
 static void
 help_activated (GSimpleAction *action,
                 GVariant      *parameter,
@@ -482,7 +461,6 @@ static GActionEntry app_entries[] = {
 	{ "new-window", new_window_activated, NULL, NULL, NULL },
 	{ "new-document", new_document_activated, NULL, NULL, NULL },
 	{ "preferences", preferences_activated, NULL, NULL, NULL },
-	{ "shortcuts", keyboard_shortcuts_activated, NULL, NULL, NULL },
 	{ "help", help_activated, NULL, NULL, NULL },
 	{ "about", about_activated, NULL, NULL, NULL },
 	{ "quit", quit_activated, NULL, NULL, NULL }
@@ -523,15 +501,20 @@ load_accels (void)
 }
 
 static GtkCssProvider *
-load_css_from_resource (const gchar *filename,
+load_css_from_resource (const gchar *css_filename,
                         gboolean     required)
 {
-	GError *error = NULL;
+	GdkScreen *screen = gdk_screen_get_default ();
+	gchar *resource_name;
 	GFile *css_file;
 	GtkCssProvider *provider;
-	gchar *resource_name;
 
-	resource_name = g_strdup_printf ("resource:///org/gnome/gedit/css/%s", filename);
+	if (screen == NULL)
+	{
+		return NULL;
+	}
+
+	resource_name = g_strdup_printf ("resource:///org/gnome/gedit/css/%s", css_filename);
 	css_file = g_file_new_for_uri (resource_name);
 	g_free (resource_name);
 
@@ -542,17 +525,15 @@ load_css_from_resource (const gchar *filename,
 	}
 
 	provider = gtk_css_provider_new ();
-
-	if (gtk_css_provider_load_from_file (provider, css_file, &error))
+	if (gtk_css_provider_load_from_file (provider, css_file, NULL))
 	{
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-		                                           GTK_STYLE_PROVIDER (provider),
-		                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		gtk_style_context_add_provider_for_screen (screen,
+							   GTK_STYLE_PROVIDER (provider),
+							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	}
 	else
 	{
-		g_warning ("Could not load css provider: %s", error->message);
-		g_error_free (error);
+		g_warning ("Could not load css provider.");
 	}
 
 	g_object_unref (css_file);
@@ -560,33 +541,58 @@ load_css_from_resource (const gchar *filename,
 }
 
 static void
-theme_changed (GtkSettings *settings,
-	       GParamSpec  *pspec,
-	       GeditApp    *app)
+update_theme (GeditApp *app)
 {
-	GeditAppPrivate *priv;
+	GeditAppPrivate *priv = gedit_app_get_instance_private (app);
+	GtkSettings *settings;
+	gchar *theme_name = NULL;
+	gchar *lowercase_theme_name;
+	gchar *css_filename;
 
-	priv = gedit_app_get_instance_private (app);
+	settings = gtk_settings_get_default ();
+	if (settings == NULL)
+	{
+		return;
+	}
 
-	gchar *theme, *lc_theme, *theme_css;
+	g_object_get (settings,
+		      "gtk-theme-name", &theme_name,
+		      NULL);
 
-	g_object_get (settings, "gtk-theme-name", &theme, NULL);
-	lc_theme = g_ascii_strdown (theme, -1);
-	g_free (theme);
+	if (theme_name == NULL)
+	{
+		return;
+	}
 
-	theme_css = g_strdup_printf ("gedit.%s.css", lc_theme);
-	g_free (lc_theme);
+	lowercase_theme_name = g_ascii_strdown (theme_name, -1);
+	g_free (theme_name);
+
+	css_filename = g_strdup_printf ("gedit.%s.css", lowercase_theme_name);
+	g_free (lowercase_theme_name);
 
 	if (priv->theme_provider != NULL)
 	{
-		gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (),
-		                                              GTK_STYLE_PROVIDER (priv->theme_provider));
+		GdkScreen *screen = gdk_screen_get_default ();
+
+		if (screen != NULL)
+		{
+			gtk_style_context_remove_provider_for_screen (screen,
+								      GTK_STYLE_PROVIDER (priv->theme_provider));
+		}
+
 		g_clear_object (&priv->theme_provider);
 	}
 
-	priv->theme_provider = load_css_from_resource (theme_css, FALSE);
+	priv->theme_provider = load_css_from_resource (css_filename, FALSE);
+	g_free (css_filename);
+}
 
-	g_free (theme_css);
+static void
+theme_name_notify_cb (GtkSettings *settings,
+		      GParamSpec  *pspec,
+		      GeditApp    *app)
+{
+	update_theme (app);
 }
 
 static void
@@ -595,9 +601,17 @@ setup_theme_extensions (GeditApp *app)
 	GtkSettings *settings;
 
 	settings = gtk_settings_get_default ();
-	g_signal_connect (settings, "notify::gtk-theme-name",
-	                  G_CALLBACK (theme_changed), app);
-	theme_changed (settings, NULL, app);
+
+	if (settings != NULL)
+	{
+		g_signal_connect_object (settings,
+					 "notify::gtk-theme-name",
+					 G_CALLBACK (theme_name_notify_cb),
+					 app,
+					 0);
+	}
+
+	update_theme (app);
 }
 
 static GMenuModel *
@@ -659,7 +673,6 @@ static void
 gedit_app_startup (GApplication *application)
 {
 	GeditAppPrivate *priv;
-	GtkCssProvider *css_provider;
 	GtkSourceStyleSchemeManager *manager;
 
 	priv = gedit_app_get_instance_private (GEDIT_APP (application));
@@ -697,7 +710,7 @@ gedit_app_startup (GApplication *application)
 	add_accelerator (GTK_APPLICATION (application), "app.new-window", "<Primary>N");
 	add_accelerator (GTK_APPLICATION (application), "app.quit", "<Primary>Q");
 	add_accelerator (GTK_APPLICATION (application), "app.help", "F1");
-	add_accelerator (GTK_APPLICATION (application), "app.shortcuts", "<Primary>question");
+	add_accelerator (GTK_APPLICATION (application), "app.preferences", "<Primary>comma");
 
 	add_accelerator (GTK_APPLICATION (application), "win.hamburger-menu", "F10");
 	add_accelerator (GTK_APPLICATION (application), "win.open", "<Primary>O");
@@ -729,8 +742,6 @@ gedit_app_startup (GApplication *application)
 
 	/* Load custom css */
 	g_object_unref (load_css_from_resource ("gedit-style.css", TRUE));
-	css_provider = load_css_from_resource ("gedit-style-os.css", FALSE);
-	g_clear_object (&css_provider);
 
 	/*
 	 * We use the default gtksourceview style scheme manager so that plugins
