@@ -45,9 +45,9 @@ typedef struct
 
 	TeplMetadata *metadata;
 
-	gchar	    *content_type;
+	gchar *content_type;
 
-	GDateTime   *time_of_last_save_or_load;
+	GDateTime *time_of_last_save_or_load;
 
 	/* The search context for the incremental search, or the search and
 	 * replace. They are mutually exclusive.
@@ -74,21 +74,20 @@ enum
 	PROP_CONTENT_TYPE,
 	PROP_MIME_TYPE,
 	PROP_EMPTY_SEARCH,
-	LAST_PROP
+	N_PROPERTIES
 };
 
-static GParamSpec *properties[LAST_PROP];
-
 enum
 {
-	LOAD,
-	LOADED,
-	SAVE,
-	SAVED,
-	LAST_SIGNAL
+	SIGNAL_LOAD,
+	SIGNAL_LOADED,
+	SIGNAL_SAVE,
+	SIGNAL_SAVED,
+	N_SIGNALS
 };
 
-static guint document_signals[LAST_SIGNAL];
+static GParamSpec *properties[N_PROPERTIES];
+static guint document_signals[N_SIGNALS];
 
 G_DEFINE_TYPE_WITH_PRIVATE (GeditDocument, gedit_document, TEPL_TYPE_BUFFER)
 
@@ -142,7 +141,7 @@ update_time_of_last_save_or_load (GeditDocument *doc)
 static const gchar *
 get_language_string (GeditDocument *doc)
 {
-	GtkSourceLanguage *lang = gedit_document_get_language (doc);
+	GtkSourceLanguage *lang = gtk_source_buffer_get_language (GTK_SOURCE_BUFFER (doc));
 
 	return lang != NULL ? gtk_source_language_get_id (lang) : NO_LANGUAGE_NAME;
 }
@@ -233,9 +232,7 @@ gedit_document_get_property (GObject    *object,
 			     GParamSpec *pspec)
 {
 	GeditDocument *doc = GEDIT_DOCUMENT (object);
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (doc);
+	GeditDocumentPrivate *priv = gedit_document_get_instance_private (doc);
 
 	switch (prop_id)
 	{
@@ -316,8 +313,8 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 */
 	properties[PROP_CONTENT_TYPE] =
 		g_param_spec_string ("content-type",
-		                     "Content Type",
-		                     "The document's Content Type",
+		                     "content-type",
+		                     "",
 		                     NULL,
 		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
@@ -328,8 +325,8 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 */
 	properties[PROP_MIME_TYPE] =
 		g_param_spec_string ("mime-type",
-		                     "MIME Type",
-		                     "The document's MIME Type",
+		                     "mime-type",
+		                     "",
 		                     "text/plain",
 		                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -340,15 +337,17 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * The property is used internally by gedit. It must not be used in a
 	 * gedit plugin. The property can be modified or removed at any time.
 	 * </warning>
+	 *
+	 * Whether the search is empty.
 	 */
 	properties[PROP_EMPTY_SEARCH] =
 		g_param_spec_boolean ("empty-search",
-		                      "Empty search",
-		                      "Whether the search is empty",
+		                      "empty-search",
+		                      "",
 		                      TRUE,
 		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_properties (object_class, LAST_PROP, properties);
+	g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
 	/**
 	 * GeditDocument::load:
@@ -360,7 +359,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * file loading (the location, encoding, etc). Plugins should not need
 	 * those parameters.
 	 */
-	document_signals[LOAD] =
+	document_signals[SIGNAL_LOAD] =
 		g_signal_new ("load",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
@@ -379,7 +378,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * signal was also emitted if an error occurred. Plugins should not need
 	 * the error parameter.
 	 */
-	document_signals[LOADED] =
+	document_signals[SIGNAL_LOADED] =
 		g_signal_new ("loaded",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
@@ -397,7 +396,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * file saving (the location, encoding, etc). Plugins should not need
 	 * those parameters.
 	 */
-	document_signals[SAVE] =
+	document_signals[SIGNAL_SAVE] =
 		g_signal_new ("save",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
@@ -417,7 +416,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * get the result of the operation with
 	 * gedit_commands_save_document_finish().
 	 */
-	document_signals[SAVED] =
+	document_signals[SIGNAL_SAVED] =
 		g_signal_new ("saved",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
@@ -484,77 +483,6 @@ save_encoding_metadata (GeditDocument *doc)
 				     NULL);
 }
 
-static gchar *
-get_default_style_scheme_id (void)
-{
-	GeditSettings *settings;
-	GSettings *editor_settings;
-	GVariant *default_value;
-	gchar *default_style_scheme_id;
-
-	settings = _gedit_settings_get_singleton ();
-	editor_settings = _gedit_settings_peek_editor_settings (settings);
-
-	default_value = g_settings_get_default_value (editor_settings, GEDIT_SETTINGS_SCHEME);
-	default_style_scheme_id = g_variant_dup_string (default_value, NULL);
-	g_variant_unref (default_value);
-
-	return default_style_scheme_id;
-}
-
-static void
-update_style_scheme (GeditDocument *doc)
-{
-	GeditSettings *settings;
-	GSettings *editor_settings;
-	gchar *style_scheme_id;
-	GtkSourceStyleSchemeManager *manager;
-	GtkSourceStyleScheme *style_scheme = NULL;
-
-	settings = _gedit_settings_get_singleton ();
-	editor_settings = _gedit_settings_peek_editor_settings (settings);
-	style_scheme_id = g_settings_get_string (editor_settings, GEDIT_SETTINGS_SCHEME);
-
-	manager = gtk_source_style_scheme_manager_get_default ();
-
-	if (style_scheme_id != NULL)
-	{
-		style_scheme = gtk_source_style_scheme_manager_get_scheme (manager, style_scheme_id);
-	}
-
-	if (style_scheme == NULL)
-	{
-		gchar *default_style_scheme_id;
-
-		default_style_scheme_id = get_default_style_scheme_id ();
-
-		g_warning_once ("Style scheme '%s' cannot be found, falling back to '%s' default style scheme.",
-				style_scheme_id,
-				default_style_scheme_id);
-
-		style_scheme = gtk_source_style_scheme_manager_get_scheme (manager, default_style_scheme_id);
-		if (style_scheme == NULL)
-		{
-			g_warning_once ("Default style scheme '%s' cannot be found, check your GtkSourceView installation.",
-					default_style_scheme_id);
-		}
-
-		g_free (default_style_scheme_id);
-	}
-
-	gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (doc), style_scheme);
-
-	g_free (style_scheme_id);
-}
-
-static void
-editor_settings_scheme_changed_cb (GSettings     *editor_settings,
-				   const gchar   *key,
-				   GeditDocument *doc)
-{
-	update_style_scheme (doc);
-}
-
 static GtkSourceLanguage *
 guess_language (GeditDocument *doc)
 {
@@ -682,13 +610,9 @@ gedit_document_init (GeditDocument *doc)
 	                 doc, "highlight-matching-brackets",
 	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_NO_SENSITIVITY);
 
-	g_signal_connect_object (editor_settings,
-				 "changed::" GEDIT_SETTINGS_SCHEME,
-				 G_CALLBACK (editor_settings_scheme_changed_cb),
-				 doc,
-				 0);
-
-	update_style_scheme (doc);
+	tepl_buffer_provide_style_scheme_id_gsetting (TEPL_BUFFER (doc),
+						      editor_settings, GEDIT_SETTINGS_SCHEME,
+						      TRUE);
 
 	g_signal_connect (doc,
 			  "notify::content-type",
@@ -810,45 +734,6 @@ set_content_type (GeditDocument *doc,
 	}
 }
 
-/* Note: this never returns %NULL. */
-gchar *
-_gedit_document_get_uri_for_display (GeditDocument *doc)
-{
-	TeplFile *file;
-	GFile *location;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
-
-	file = tepl_buffer_get_file (TEPL_BUFFER (doc));
-	location = tepl_file_get_location (file);
-
-	if (location == NULL)
-	{
-		return tepl_file_get_short_name (file);
-	}
-	else
-	{
-		return g_file_get_parse_name (location);
-	}
-}
-
-/**
- * gedit_document_get_short_name_for_display:
- * @doc: a #GeditDocument.
- *
- * Note: this never returns %NULL.
- **/
-gchar *
-gedit_document_get_short_name_for_display (GeditDocument *doc)
-{
-	TeplFile *file;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
-
-	file = tepl_buffer_get_file (TEPL_BUFFER (doc));
-	return tepl_file_get_short_name (file);
-}
-
 gchar *
 gedit_document_get_content_type (GeditDocument *doc)
 {
@@ -1032,8 +917,9 @@ gedit_document_saved_real (GeditDocument *doc)
 				 doc);
 }
 
+/* TODO: remove this function. */
 gboolean
-gedit_document_is_untitled (GeditDocument *doc)
+_gedit_document_is_untitled (GeditDocument *doc)
 {
 	TeplFile *file;
 
@@ -1086,20 +972,6 @@ gedit_document_set_language (GeditDocument     *doc,
 	set_language (doc, lang, TRUE);
 }
 
-/**
- * gedit_document_get_language:
- * @doc:
- *
- * Return value: (transfer none):
- */
-GtkSourceLanguage *
-gedit_document_get_language (GeditDocument *doc)
-{
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-
-	return gtk_source_buffer_get_language (GTK_SOURCE_BUFFER (doc));
-}
-
 glong
 _gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 {
