@@ -5,7 +5,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
- * Copyright (C) 2014 Sébastien Wilmet
+ * Copyright (C) 2014-2020 Sébastien Wilmet
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,20 +24,19 @@
 #ifndef GEDIT_DOCUMENT_H
 #define GEDIT_DOCUMENT_H
 
-#include <gtksourceview/gtksource.h>
+#include <tepl/tepl.h>
 
 G_BEGIN_DECLS
 
 #define GEDIT_TYPE_DOCUMENT (gedit_document_get_type())
 
-G_DECLARE_DERIVABLE_TYPE (GeditDocument, gedit_document, GEDIT, DOCUMENT, GtkSourceBuffer)
+G_DECLARE_DERIVABLE_TYPE (GeditDocument, gedit_document, GEDIT, DOCUMENT, TeplBuffer)
 
 struct _GeditDocumentClass
 {
-	GtkSourceBufferClass parent_class;
+	TeplBufferClass parent_class;
 
 	/* Signals */
-	void (* cursor_moved)		(GeditDocument *document);
 
 	void (* load)			(GeditDocument *document);
 
@@ -52,27 +51,12 @@ GeditDocument   *gedit_document_new				(void);
 
 GtkSourceFile	*gedit_document_get_file			(GeditDocument       *doc);
 
-gchar		*gedit_document_get_short_name_for_display	(GeditDocument       *doc);
-
 gchar		*gedit_document_get_content_type		(GeditDocument       *doc);
 
 gchar		*gedit_document_get_mime_type			(GeditDocument       *doc);
 
-gboolean	 gedit_document_is_untouched			(GeditDocument       *doc);
-
-gboolean	 gedit_document_is_untitled			(GeditDocument       *doc);
-
-gboolean	 gedit_document_goto_line			(GeditDocument       *doc,
-								gint                 line);
-
-gboolean	 gedit_document_goto_line_offset		(GeditDocument       *doc,
-								 gint                 line,
-								 gint                 line_offset);
-
 void 		 gedit_document_set_language			(GeditDocument       *doc,
 								 GtkSourceLanguage   *lang);
-GtkSourceLanguage
-		*gedit_document_get_language			(GeditDocument       *doc);
 
 gchar		*gedit_document_get_metadata			(GeditDocument       *doc,
 								 const gchar         *key);
