@@ -22,7 +22,7 @@
 
 #include "gedit-multi-notebook.h"
 
-#include "gedit-enum-types.h"
+#include "gedit-enum-types-private.h"
 #include "gedit-settings.h"
 #include "gedit-tab-private.h"
 #include "gedit-tab.h"
@@ -689,7 +689,7 @@ gedit_multi_notebook_init (GeditMultiNotebook *mnb)
 }
 
 GeditMultiNotebook *
-gedit_multi_notebook_new ()
+gedit_multi_notebook_new (void)
 {
 	return g_object_new (GEDIT_TYPE_MULTI_NOTEBOOK, NULL);
 }
