@@ -29,7 +29,6 @@
 
 #include "gedit-notebook.h"
 #include "gedit-tab-label.h"
-#include "gedit-marshal.h"
 
 #define GEDIT_NOTEBOOK_GROUP_NAME "GeditNotebookGroup"
 
@@ -147,7 +146,6 @@ gedit_notebook_button_press_event (GtkWidget      *widget,
 	GtkNotebook *notebook = GTK_NOTEBOOK (widget);
 
 	if (event->type == GDK_BUTTON_PRESS &&
-	    event->button == GDK_BUTTON_SECONDARY &&
 	    (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
 	{
 		gint tab_clicked;
@@ -158,10 +156,19 @@ gedit_notebook_button_press_event (GtkWidget      *widget,
 			GtkWidget *tab;
 
 			tab = gtk_notebook_get_nth_page (notebook, tab_clicked);
+			switch (event->button)
+			{
+				case GDK_BUTTON_SECONDARY:
+					g_signal_emit (G_OBJECT (widget), signals[SHOW_POPUP_MENU], 0, event, tab);
+					return GDK_EVENT_STOP;
 
-			g_signal_emit (G_OBJECT (widget), signals[SHOW_POPUP_MENU], 0, event, tab);
+				case GDK_BUTTON_MIDDLE:
+					g_signal_emit (G_OBJECT (notebook), signals[TAB_CLOSE_REQUEST], 0, tab);
+					return GDK_EVENT_STOP;
 
-			return GDK_EVENT_STOP;
+				default:
+					break;
+			}
 		}
 	}
 
@@ -462,8 +469,7 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditNotebookClass, tab_close_request),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      GEDIT_TYPE_TAB);
@@ -473,8 +479,7 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (GeditNotebookClass, show_popup_menu),
-			      NULL, NULL,
-			      gedit_marshal_VOID__BOXED_OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
@@ -485,8 +490,7 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		              G_STRUCT_OFFSET (GeditNotebookClass, change_to_page),
-		              NULL, NULL,
-		              gedit_marshal_BOOLEAN__INT,
+		              NULL, NULL, NULL,
 		              G_TYPE_BOOLEAN, 1,
 		              G_TYPE_INT);
 
@@ -617,10 +621,21 @@ gedit_notebook_move_tab (GeditNotebook *src,
 	g_return_if_fail (src != dest);
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 
-	/* make sure the tab isn't destroyed while we move it */
+	/* Make sure the tab isn't destroyed while we move it. */
 	g_object_ref (tab);
+
+	/* Make sure the @src notebook isn't destroyed during the tab
+	 * detachment, to prevent a crash in gtk_notebook_detach_tab(). In fact,
+	 * if @tab is the last tab of @src, and if @src is not the last notebook
+	 * of the GeditMultiNotebook, then @src will be destroyed when
+	 * gtk_container_remove() is called by gtk_notebook_detach_tab().
+	 */
+	g_object_ref (src);
 	gtk_notebook_detach_tab (GTK_NOTEBOOK (src), GTK_WIDGET (tab));
+	g_object_unref (src);
+
 	gedit_notebook_add_tab (dest, tab, dest_position, TRUE);
+
 	g_object_unref (tab);
 }
 
