@@ -2071,14 +2071,49 @@ load_finish (GeditTab     *tab,
 	return g_task_propagate_boolean (G_TASK (result), NULL);
 }
 
-void
-_gedit_tab_load (GeditTab                *tab,
-		 GFile                   *location,
-		 const GtkSourceEncoding *encoding,
-		 gint                     line_pos,
-		 gint                     column_pos,
-		 gboolean                 create)
+static void
+tab_load_cb (GObject      *source_object,
+	     GAsyncResult *result,
+	     gpointer      user_data)
 {
+	GeditTab *tab = GEDIT_TAB (source_object);
+	load_finish (tab, result);
+}
+
+/**
+ * gedit_tab_load_file:
+ * @tab: a #GeditTab.
+ * @location: the #GFile to load.
+ * @encoding: (nullable): a #GtkSourceEncoding, or %NULL.
+ * @line_pos: the line position to visualize.
+ * @column_pos: the column position to visualize.
+ * @create: %TRUE to show no errors if @location doesn't exist.
+ *
+ * This function tries to load @location into @tab. It is usually called only on
+ * a newly-created tab.
+ *
+ * If @location doesn't exist, the behavior depends on @create:
+ * - If @create is %FALSE, an error is shown.
+ * - If @create is %TRUE, an empty #GeditDocument is created without error (but
+ *   the file is not yet created on disk).
+ *
+ * The @tab needs to be in %GEDIT_TAB_STATE_NORMAL. The previous
+ * #GtkTextBuffer's content is lost.
+ *
+ * Since: 45
+ */
+void
+gedit_tab_load_file (GeditTab                *tab,
+		     GFile                   *location,
+		     const GtkSourceEncoding *encoding,
+		     gint                     line_pos,
+		     gint                     column_pos,
+		     gboolean                 create)
+{
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (G_IS_FILE (location));
+	g_return_if_fail (tab->state == GEDIT_TAB_STATE_NORMAL);
+
 	if (tab->cancellable != NULL)
 	{
 		g_cancellable_cancel (tab->cancellable);
@@ -2094,7 +2129,7 @@ _gedit_tab_load (GeditTab                *tab,
 		    column_pos,
 		    create,
 		    tab->cancellable,
-		    (GAsyncReadyCallback) load_finish,
+		    tab_load_cb,
 		    NULL);
 }
 
@@ -2142,13 +2177,33 @@ load_stream_async (GeditTab                *tab,
 	launch_loader (loading_task, encoding);
 }
 
+/**
+ * gedit_tab_load_stream:
+ * @tab: a #GeditTab.
+ * @stream: the #GInputStream to load, e.g. stdin.
+ * @encoding: (nullable): a #GtkSourceEncoding, or %NULL.
+ * @line_pos: the line position to visualize.
+ * @column_pos: the column position to visualize.
+ *
+ * Loads @stream into @tab. This function is usually called only on a
+ * newly-created tab.
+ *
+ * The @tab needs to be in %GEDIT_TAB_STATE_NORMAL. The previous
+ * #GtkTextBuffer's content is lost.
+ *
+ * Since: 45
+ */
 void
-_gedit_tab_load_stream (GeditTab                *tab,
-			GInputStream            *stream,
-			const GtkSourceEncoding *encoding,
-			gint                     line_pos,
-			gint                     column_pos)
+gedit_tab_load_stream (GeditTab                *tab,
+		       GInputStream            *stream,
+		       const GtkSourceEncoding *encoding,
+		       gint                     line_pos,
+		       gint                     column_pos)
 {
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (G_IS_INPUT_STREAM (stream));
+	g_return_if_fail (tab->state == GEDIT_TAB_STATE_NORMAL);
+
 	if (tab->cancellable != NULL)
 	{
 		g_cancellable_cancel (tab->cancellable);
@@ -2163,7 +2218,7 @@ _gedit_tab_load_stream (GeditTab                *tab,
 			   line_pos,
 			   column_pos,
 			   tab->cancellable,
-			   (GAsyncReadyCallback) load_finish,
+			   tab_load_cb,
 			   NULL);
 }
 
@@ -2222,7 +2277,7 @@ _gedit_tab_revert (GeditTab *tab)
 
 	revert_async (tab,
 		      tab->cancellable,
-		      (GAsyncReadyCallback) load_finish,
+		      tab_load_cb,
 		      NULL);
 }
 
