@@ -79,7 +79,7 @@ struct _GeditWindowPrivate
 	guint tab_width_id;
 	guint language_changed_id;
 
-	/* Headerbars */
+	/* Headerbars (can be NULL) */
 	GtkHeaderBar *side_headerbar;
 	GeditHeaderBar *headerbar;
 
@@ -136,9 +136,9 @@ enum
 	TARGET_XDNDDIRECTSAVE
 };
 
-static const GtkTargetEntry drop_types [] = {
-	{ "XdndDirectSave0", 0, TARGET_XDNDDIRECTSAVE }, /* XDS Protocol Type */
-	{ "text/uri-list", 0, TARGET_URI_LIST}
+static const GtkTargetEntry drop_types[] = {
+	{ (gchar *) "XdndDirectSave0", 0, TARGET_XDNDDIRECTSAVE }, /* XDS Protocol Type */
+	{ (gchar *) "text/uri-list", 0, TARGET_URI_LIST }
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GeditWindow, gedit_window, GTK_TYPE_APPLICATION_WINDOW)
@@ -989,7 +989,7 @@ bracket_matched_cb (GtkSourceBuffer           *buffer,
 	{
 		gedit_statusbar_flash_message (window->priv->statusbar,
 					       window->priv->bracket_match_message_cid,
-					       msg);
+					       "%s", msg);
 		g_free (msg);
 	}
 	else
