@@ -26,6 +26,14 @@ from gi.repository import GObject, Gtk
 from . import helper
 from .substitutionparser import SubstitutionParser
 
+try:
+    import gettext
+    gettext.bindtextdomain('gedit')
+    gettext.textdomain('gedit')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
+
 # These are places in a view where the cursor can go and do things
 class Placeholder:
     def __init__(self, view, tabstop, environ, defaults, begin):
@@ -372,7 +380,7 @@ class PlaceholderExpand(Placeholder):
                 if tabstop == 0:
                     continue
 
-                if self.mirror_text[tabstop] == None:
+                if self.mirror_text[tabstop] is None:
                     return False
 
         return self.run_update()
@@ -420,7 +428,7 @@ class PlaceholderShell(PlaceholderExpand):
 
         self.set_text(str.join('', self.shell_output).rstrip('\n'))
 
-        if self.default == None:
+        if self.default is None:
             self.default = self.get_text()
             self.leave()
 
@@ -607,7 +615,7 @@ class PlaceholderEval(PlaceholderExpand):
 
                 return False
 
-            if result == None:
+            if result is None:
                 # sys.stderr.write("%s:\n>> %s\n" % (_('The following python code, run in a snippet, does not return a value'), "\n>> ".join(self.command.split("\n"))))
                 result = ''
 
