@@ -249,6 +249,20 @@ update_ui (GeditTimePlugin *plugin)
 	                             gtk_text_view_get_editable (GTK_TEXT_VIEW (view)));
 }
 
+static void
+add_keyboard_shortcut (GtkApplication *app)
+{
+	const gchar *accels[] = { "<Shift><Alt>D", NULL };
+	gtk_application_set_accels_for_action (app, "win.time", accels);
+}
+
+static void
+remove_keyboard_shortcut (GtkApplication *app)
+{
+	const gchar *accels[] = {  NULL };
+	gtk_application_set_accels_for_action (app, "win.time", accels);
+}
+
 static void
 gedit_time_plugin_app_activate (GeditAppActivatable *activatable)
 {
@@ -259,6 +273,8 @@ gedit_time_plugin_app_activate (GeditAppActivatable *activatable)
 
 	priv = GEDIT_TIME_PLUGIN (activatable)->priv;
 
+	add_keyboard_shortcut (GTK_APPLICATION (priv->app));
+
 	priv->menu_ext = gedit_app_activatable_extend_menu (activatable, "tools-section");
 	item = g_menu_item_new (_("In_sert Date and Time…"), "win.time");
 	gedit_menu_extension_append_menu_item (priv->menu_ext, item);
@@ -274,6 +290,8 @@ gedit_time_plugin_app_deactivate (GeditAppActivatable *activatable)
 
 	priv = GEDIT_TIME_PLUGIN (activatable)->priv;
 
+	remove_keyboard_shortcut (GTK_APPLICATION (priv->app));
+
 	g_clear_object (&priv->menu_ext);
 }
 
@@ -647,7 +665,7 @@ get_configure_widget (GeditTimePlugin *plugin)
 	GeditTimePluginPromptType prompt_type;
 	gchar *sf;
 	GtkBuilder *builder;
-	gchar *root_objects[] = {
+	const gchar *root_objects[] = {
 		"time_dialog_content",
 		NULL
 	};
@@ -659,7 +677,7 @@ get_configure_widget (GeditTimePlugin *plugin)
 
 	builder = gtk_builder_new ();
 	gtk_builder_add_objects_from_resource (builder, "/org/gnome/gedit/plugins/time/ui/gedit-time-setup-dialog.ui",
-	                                       root_objects, NULL);
+	                                       (gchar **)root_objects, NULL);
 	widget->content = GTK_WIDGET (gtk_builder_get_object (builder, "time_dialog_content"));
 	g_object_ref (widget->content);
 	viewport = GTK_WIDGET (gtk_builder_get_object (builder, "formats_viewport"));
